@@ -2,16 +2,18 @@ package App::Toodledo::Folder;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '1.00';
 
 use Carp;
 use Moose;
+use MooseX::Method::Signatures;
+use App::Toodledo::FolderInternal;
 
-has id          => ( is => 'rw', isa => 'Int' );
-has name        => ( is => 'rw', isa => 'Str' );
-has private     => ( is => 'rw', isa => 'Int' );
-has archived    => ( is => 'rw', isa => 'Int' );
-has order       => ( is => 'rw', isa => 'Int' );
+extends 'App::Toodledo::InternalWrapper';
+
+has object => ( is => 'ro', isa => 'App::Toodledo::FolderInternal',
+	        default => sub { App::Toodledo::FolderInternal->new },
+	        handles => sub { __PACKAGE__->internal_attributes( $_[1] ) } );
 
 1;
 
@@ -31,13 +33,8 @@ App::Toodledo::Folder - class encapsulating a Toodledo folder
 =head1 DESCRIPTION
 
 This class provides accessors for the properties of a Toodledo folder.
-The following attributes are defined:
-
-  id
-  name
-  private
-  archived
-  order
+The attributes of a folder are defined in the L<App::Toodledo::FolderRole>
+module.
 
 =head1 AUTHOR
 
@@ -51,7 +48,7 @@ Toodledo API documentation: L<http://www.toodledo.com/info/api_doc.php>.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2009 Peter J. Scott, all rights reserved.
+Copyright 2009-2011 Peter J. Scott, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
